@@ -60,6 +60,17 @@ class IsoRegistry:
                     self.register(iso_code, cls)
 
     def get_calendar_class(self, iso_code):
+        """
+        Alias for the ``get(iso_code)`` method.
+
+        This alias will be deprecated in a further release.
+        """
+        warnings.warn("The ``get_calendar_class(iso_code)`` method will soon"
+                      " be deprecated. Please use ``get(iso_code)`` instead.",
+                      DeprecationWarning)
+        return self.get(iso_code)
+
+    def get(self, iso_code):
         """
         Retrieve calendar class associated with given ``iso_code``.
 
@@ -91,24 +102,6 @@ class IsoRegistry:
                 items[key] = value
         return items
 
-    def items(self, region_codes=None, include_subregions=False):
-        """
-        Returns calendar classes for regions
-
-        :param region_codes list of ISO codes for selected regions. If empty,
-                            the function will return all items from the
-                            registry.
-        :param include_subregions boolean if subregions
-        of selected regions should be included in result
-        :rtype dict
-        :return dict where keys are ISO codes strings
-        and values are calendar classes
-        """
-        warnings.warn("The ``items()`` method will soon be deprecated."
-                      " Please use ``get_calendars()`` instead.",
-                      DeprecationWarning)
-        return self.get_calendars(region_codes, include_subregions)
-
     def get_calendars(self, region_codes=None, include_subregions=False):
         """
         Returns calendar classes for regions
