@@ -35,7 +35,6 @@ from ..europe import (
     Serbia,
     Spain, Catalonia,
     Slovenia,
-    Switzerland, Vaud, Geneva,
     Ukraine,
     UnitedKingdom,
     UnitedKingdomNorthernIreland,
@@ -1303,80 +1302,6 @@ class SloveniaTest(GenericCalendarTest):
         self.assertIn(date(2017, 1, 2), holidays)
 
 
-class SwitzerlandTest(GenericCalendarTest):
-    cal_class = Switzerland
-
-    def test_year_2015(self):
-        holidays = self.cal.holidays_set(2015)
-        self.assertIn(date(2015, 1, 1), holidays)
-        self.assertIn(date(2015, 1, 2), holidays)
-        self.assertIn(date(2015, 4, 3), holidays)
-        self.assertIn(date(2015, 4, 5), holidays)
-        self.assertIn(date(2015, 4, 6), holidays)
-        self.assertIn(date(2015, 5, 1), holidays)
-        self.assertIn(date(2015, 5, 14), holidays)
-        self.assertIn(date(2015, 5, 24), holidays)
-        self.assertIn(date(2015, 5, 25), holidays)
-        self.assertIn(date(2015, 8, 1), holidays)
-        self.assertIn(date(2015, 12, 25), holidays)
-        self.assertIn(date(2015, 12, 26), holidays)
-
-    def test_year_2016(self):
-        holidays = self.cal.holidays_set(2016)
-        self.assertIn(date(2016, 1, 1), holidays)
-        self.assertIn(date(2016, 1, 2), holidays)
-        self.assertIn(date(2016, 3, 25), holidays)
-        self.assertIn(date(2016, 3, 28), holidays)
-        self.assertIn(date(2016, 5, 1), holidays)
-        self.assertIn(date(2016, 5, 5), holidays)
-        self.assertIn(date(2016, 5, 15), holidays)
-        self.assertIn(date(2016, 5, 16), holidays)
-        self.assertIn(date(2016, 8, 1), holidays)
-        self.assertIn(date(2016, 12, 25), holidays)
-        self.assertIn(date(2016, 12, 26), holidays)
-
-
-class VaudTest(GenericCalendarTest):
-    cal_class = Vaud
-
-    def test_year_2016(self):
-        holidays = self.cal.holidays_set(2016)
-        self.assertIn(date(2016, 9, 19), holidays)
-        self.assertNotIn(date(2016, 5, 1), holidays)
-        self.assertNotIn(date(2016, 12, 26), holidays)
-
-    def test_year_2017(self):
-        holidays = self.cal.holidays_set(2017)
-        self.assertIn(date(2017, 9, 18), holidays)
-        self.assertNotIn(date(2017, 5, 1), holidays)
-        self.assertNotIn(date(2017, 12, 26), holidays)
-
-
-class GenevaTest(GenericCalendarTest):
-    cal_class = Geneva
-
-    def test_year_2018(self):
-        holidays = self.cal.holidays_set(2018)
-        self.assertIn(date(2018, 9, 6), holidays)
-        self.assertIn(date(2018, 12, 31), holidays)
-        self.assertNotIn(date(2018, 5, 1), holidays)
-        self.assertNotIn(date(2018, 12, 26), holidays)
-
-    def test_year_2019(self):
-        holidays = self.cal.holidays_set(2019)
-        self.assertIn(date(2019, 9, 5), holidays)
-        self.assertIn(date(2019, 12, 31), holidays)
-        self.assertNotIn(date(2019, 5, 1), holidays)
-        self.assertNotIn(date(2019, 12, 26), holidays)
-
-    def test_year_2020(self):
-        holidays = self.cal.holidays_set(2020)
-        self.assertIn(date(2020, 9, 10), holidays)
-        self.assertIn(date(2020, 12, 31), holidays)
-        self.assertNotIn(date(2020, 5, 1), holidays)
-        self.assertNotIn(date(2020, 12, 26), holidays)
-
-
 class EstoniaTest(GenericCalendarTest):
     cal_class = Estonia
 
